# 🌈 Twig to Single Directory Component (SDC) Converter

## 📝 Overview
This codegen tool simplifies the conversion of existing Twig components into SDC compatible components, saving time and reducing manual effort. By analyzing the provided Twig code, the tool automatically generates the .component.yml file, eliminating the need for manual setup entirely.

While the tool streamlines the conversion process, it might not cover every scenario perfectly. Some props or specific cases may need a little extra attention, which is why we recommend reviewing the generated files to ensure everything fits your unique project requirements.

Think of Twig to SDC as a helpful assistant that takes care of the heavy lifting, while you fine-tune the details where needed.

---

## ⚙️ **Usage**
1. Run the Drush command to initiate the tool:
   ```bash
   drush twig_to_sdc:generate /path/to/directory
2. The tool will generate a `.component.yml` file in the same location as each Twig file.
3. Review the generated `.component.yml` files, test them in your environment, and adjust them as needed.

---

## 🌟 Key features

### 1. AI-Powered annotation
Utilizes AI capabilities to:
- Generate intelligent comments for Twig templates
- Creates meaningful descriptions for variables
- Provides example values based on variable types and context
- Provide clear documentation for variables and components

### 2. Comprehensive twig template parsing
The module offers comprehensive parsing of Twig files, capable of extracting:
- Analyze Twig file content using advanced regular expressions
- Detect variable types, descriptions, and potential default values
- Basic variables with descriptions and types
- Slot definitions
- Conditional variables
- Included component references
- Boolean variables
- Enumerated values
- Object and array structures
- Default values
- Conditional and null-coalescing operations
- Generate structured metadata about the component

### 3. .component.yml generation
Automatically generates SDC required `.component.yml` files with:
- Converts parsed information into a standardized SDC component.yml file
- Provides proper formatting.
- Determines required fields based on variable characteristics
